/***************************************************************************
 *   Copyright (C) 2004 by Alexander Dymo                                  *
 *   adymo@kdevelop.org                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "dockarea.h"

#include <qlayout.h>
#include <qregion.h>
#include <qpointarray.h>
#include <qobjectlist.h>

#include <kdebug.h>

#include "dockwidget.h"
#include "placewidget.h"

#include <qlineedit.h>

namespace Ideal {

DockArea::DockArea(PlacePolicy placePolicy, QWidget *parent, const char *name)
    :QWidget(parent, name), m_placePolicy(placePolicy), m_mode(Area)
{
/*    QGridLayout *l = new QGridLayout(this, 0, 0);
    QSplitter *sl1*/
    m_layout = new QVBoxLayout(this, 0, 0);
//    m_layout->addWidget(new QLineEdit(this));
//    m_layout->setAutoAdd(true);
}

DockArea::~DockArea()
{
}

void DockArea::placeDockWidget(DockWidget *w, Place place, DockInfo *info)
{
    kdDebug() << "DockArea::placeDockWidget: " << name() << endl;

    PlaceWidget *pw = placeWidget(place);
    pw->show();
    w->reparent(pw, QPoint(0, 0), true);
    pw->addWidget(w, info);
}

void DockArea::drawDockPlace(QRect dockPlace)
{
}

QRect DockArea::dockPlace(DockWidget *w)
{
    return QRect();
}

PlaceWidget *DockArea::placeWidget(Place place)
{    
    if (m_placePolicy == DockArea::Bottom)
        place = Ideal::Bottom;
    if (m_placeWidgets.contains(place))
        return m_placeWidgets[place];
    else
    {
        Orientation o;
        switch (place)
        {
            case Ideal::Left:
            case Ideal::Right:
                o = Vertical;
                break;
            case Ideal::Top:
            case Ideal::Bottom:
                o = Horizontal;
        }
        kdDebug() << "DockArea::placeWidget: " << name() << endl;
        PlaceWidget *pw = new PlaceWidget(o, this);
        m_placeWidgets[place] = pw;
        m_layout->addWidget(pw);
        return pw;
    }
}

QRegion makeRegion(const QPoint &p1, const QPoint &p2, const QPoint &p3)
{
    QPointArray ar(3);
    ar.setPoint(0, p1); ar.setPoint(1, p2); ar.setPoint(2, p3);
    return QRegion(ar);
}

Place DockArea::placeHint(QPoint pos)
{
    QPoint p = mapFromGlobal(pos);
    QPoint p1 = QPoint(x(), y());
    QPoint p2 = QPoint(x(), y() + height()/2);
    QPoint p3 = QPoint(x(), y() + height());
    QPoint p4 = QPoint(x() + width()/2, y());
    QPoint p5 = QPoint(x() + width()/2, y() + height()/2);
    QPoint p6 = QPoint(x() + width()/2, y() + height());
    QPoint p7 = QPoint(x() + width(), y());
    QPoint p8 = QPoint(x() + width(), y() + height()/2);
    QPoint p9 = QPoint(x() + width(), y() + height());
    QRegion r1 = makeRegion(p1, p2, p5);
    QRegion r2 = makeRegion(p2, p5, p3);
    QRegion r3 = makeRegion(p1, p4, p5);
    QRegion r4 = makeRegion(p3, p5, p6);
    QRegion r5 = makeRegion(p4, p5, p7);
    QRegion r6 = makeRegion(p5, p6, p9);
    QRegion r7 = makeRegion(p5, p7, p8);
    QRegion r8 = makeRegion(p5, p8, p9);
    
    return Ideal::Bottom;
}

bool DockArea::isEmpty() const
{
    QObjectList *l = queryList("Ideal::DockWidget");
//     kdDebug() << "=== num: " << l->count() << endl;
    bool e = l->isEmpty();
    delete l;
    return e && (m_mode == DockContainer);
}

void DockArea::setMode(Mode mode)
{
    m_mode = mode;
}

}
#include <qpainter.h>
void Ideal::DockArea::paintEvent( QPaintEvent * ev )
{
    QPainter p(this);
    p.fillRect(rect(), QBrush(QColor(10, 10, 10)));
}

#include "dockarea.moc"
