/***************************************************************************
 *   Copyright (C) 2004 by Alexander Dymo                                  *
 *   adymo@kdevelop.org                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef IDEALDOCKAREA_H
#define IDEALDOCKAREA_H

#include <qmap.h>
#include <qwidget.h>

#include "comdefs.h"

class QGridLayout;
class QBoxLayout;

namespace Ideal {

class DockWidget;
class DockInfo;
class PlaceWidget;

/**
@short An area to drop docks.

Takes care about sizing and placement of dock widgets.
*/
class DockArea: public QWidget {
    Q_OBJECT
public:
    enum PlacePolicy { AllSides, Bottom };
    /**Mode of an area.*/
    enum Mode { Area /**<Usual area*/, DockContainer /**<Dock container which was created for undocked dock widget. Containers are deleted when they become empty.*/ };
    
    /**@param name required for saving of dock positions to work*/
    DockArea(PlacePolicy placePolicy, QWidget *parent, const char *name);
    ~DockArea();
    
    /**Places dock widget in the area.*/
    void placeDockWidget(DockWidget *w, Place place, DockInfo *info);
    
    /**Gets an area to place the dock in.*/
    QRect dockPlace(DockWidget *w);
    /**Draws placeholder for a dock.*/
    void drawDockPlace(QRect dockPlace);
    /**Returns the place to put dockwidget into.*/
    Place placeHint(QPoint pos);

    virtual void paintEvent(QPaintEvent *ev);

    /**Sets the mode of a dock area.*/
    void setMode(Mode mode);
    /**@returns true if no dock widgets are docked into this window
    and the area itself is a toplevel dock container.*/    
    bool isEmpty() const;

protected:
    PlaceWidget *placeWidget(Place place);
        
private:
    QMap<Place, PlaceWidget*> m_placeWidgets;
    PlacePolicy m_placePolicy;
    QBoxLayout *m_layout;
    
    Mode m_mode;
};

}

#endif
