/***************************************************************************
 *   Copyright (C) 2004 by Alexander Dymo                                  *
 *   adymo@kdevelop.org                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "dockheaderbutton.h"

#include <qstyle.h>
#include <qpainter.h>
#include <qtooltip.h>

#include <klocale.h>
#include <kdebug.h>

namespace Ideal {

static const char* const dock_xpm[]={
"6 6 2 1",
"# c black",
". c None",
"......",
".#....",
"..#..#",
"...#.#",
"....##",
"..####"};

static const char* const detach_xpm[]={
"5 5 2 1",
"# c black",
". c None",
"####.",
"##...",
"#.#..",
"#..#.",
"....#"};

static const char* const overlap_xpm[]={
"5 5 2 1",
"# c black",
". c None",
"#####",
"#...#",
"#...#",
"#...#",
"#####"};

DockHeaderButton::DockHeaderButton(Type type, QWidget *parent, const char *name)
    :QToolButton(parent, name), m_type(type)
{
    setFixedSize(style().stylePixmap(QStyle::SP_TitleBarCloseButton , this).size());
    setTypeBehaviour();    
    setAutoRaise(true);
}

DockHeaderButton::~DockHeaderButton()
{
}

void DockHeaderButton::setType(Type type)
{
    m_type = type;
    setTypeBehaviour();
    repaint();
}

void DockHeaderButton::setTypeBehaviour()
{
    switch (m_type)
    {
        case Close:  
            setPixmap(style().stylePixmap(QStyle::SP_TitleBarCloseButton , this));
            QToolTip::add(this, i18n("Close"));
            break;
        case Overlap:
            setPixmap(const_cast<const char**>(overlap_xpm));
            QToolTip::add(this, i18n("Overlap"));
            setToggleButton(true);
            break;
        case Detach:
            setPixmap(const_cast<const char**>(detach_xpm));
            QToolTip::add(this, i18n("Detach"));
            break;
        case Dock:
            setPixmap(const_cast<const char**>(dock_xpm));
            QToolTip::add(this, i18n("Dock"));
            break;
    }
}

}

#include "dockheaderbutton.moc"
